import time
from typing import Any, Dict


class Cache:
    """
    A simple cache implementation that stores items with a TTL.

    Args:
        ttl (int): Time to live for cache items in seconds.

    Attributes:
        _cache (Dict[str, Dict[str, Any]): Dictionary to store data and their expiry times.
        _ttl (int): Time to live for cache items in seconds.


    Examples:
        >>> cache = Cache(ttl=60)
        >>> cache.set("key", "value")
        >>> cache.get("key")
    """

    def __init__(self, ttl: int = 300):
        self._cache: Dict[str, Dict[str, Any]] = {}
        self._ttl = ttl

    def get(self, key: str) -> Any:
        """Retrieve an item from the cache if it exists and is not expired."""
        if key in self._cache:
            item = self._cache[key]
            if time.time() < item["expiry"]:
                return item["data"]
            else:
                # Remove expired item
                del self._cache[key]
        return None

    def set(self, key: str, data: Any) -> None:
        """Store an item in the cache with the current timestamp."""
        self._cache[key] = {"data": data, "expiry": time.time() + self._ttl}
